# $Id: simclient.py,v 1.10 2002/02/17 21:57:08 marijn Exp $

# An air traffic simulation game. 
# Copyright (C) 2000,1,2  Marijn Vriens <marijn@sanity.dhs.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import setup
import os

os.environ["IDLPATH"] = setup.dir_idl
import CORBA, SimulationServer, SimulationServer__POA

import absclient

def SimClient(fifo=None):
    if _SimClient.instance == None:
        _SimClient.instance = _SimClient(fifo)
    return _SimClient.instance

class _SimClient(absclient.AbsClient):
    instance = None
    def __init__(self, fifo):
        absclient.AbsClient.__init__(self, fifo)
        self._connnr = 0
    def _genExceptionNameClassLink(self):
        absclient.AbsClient._genExceptionNameClassLink(self)
        self._exceptionHandlerClassDict[SimulationServer.NoExist] = "NoExist"
        self._exceptionHandlerClassDict[SimulationServer.NickTaken] = "NickTaken"
        self._exceptionHandlerClassDict[SimulationServer.MissingParameter] = "MissingParameter"
        self._exceptionHandlerClassDict[SimulationServer.NoAuthorityOverObject] = "NoAuthorityOverObject"
    def connect_impl(self, ior, nick):
        self.handle = self._orb.string_to_object(ior)
        try:
            self._connnr = self.handle.connect(nick)
        except(SimulationServer.NickTaken):
            return 0
        return self._connnr
    def disconnect_impl(self):
        self.handle.disconnect(self._connnr)
    def subscribe_impl(self, oid):
        self.handle.subscribe(self._connnr, oid)
    def unsubscribe_impl(self, oid):
        self.handle.unsubscribe(self._connnr, oid)
    def getUpdate_impl(self):
        d = self.handle.getUpdate(self._connnr)
        return d        
    def giveOrder_impl(self, oid, ordData):
        order = SimulationServer.OrderType()
        order.speed   = ordData['speed']
        order.heading = ordData['heading']
        order.height  = ordData['altitude']
        returnedOrder = self.handle.giveOrder(self._connnr, oid, order)
        return returnedOrder
    
# $Log: simclient.py,v $
# Revision 1.10  2002/02/17 21:57:08  marijn
# Added generalized exception handling w/ callbacks
#
# Revision 1.9  2002/02/07 12:54:06  marijn
# Reordered windows, Added plane ordering functionality
#
# Revision 1.8  2002/02/02 17:23:57  marijn
# Updated copyright information
#
# Revision 1.7  2002/01/16 18:09:54  marijn
# Changed from named-pipes to normal ones.
# Added AbsClient.executeWithDelay() that executes the event later.
# Fixed some inter-threading bugs. the Exception de-syncing is still here.
#
# Revision 1.6  2002/01/14 15:49:00  marijn
# beter generalized IDL structures.
#
# Revision 1.5  2001/12/26 02:33:59  marijn
# Added SimClient to threaded model
#
# Revision 1.4  2001/12/25 02:06:04  marijn
# Moved to absclient.py strategy
#
# Revision 1.3  2001/11/27 21:03:35  marijn
# Spawns thread for server comunications.
#
# Revision 1.2  2001/11/19 00:25:39  marijn
# py merged back into HEAD
#
# Revision 1.1.2.1  2001/11/16 04:00:12  marijn
# Client connects to simserver
#
